import algosdk, { Account, Algodv2, LogicSigAccount } from "algosdk";
import { ChainId } from "../utils/consts";
export declare let ALGO_TOKEN: string;
export declare let ALGOD_ADDRESS: string;
export declare let ALGOD_PORT: number;
export declare let CORE_ID: number;
export declare let TOKEN_BRIDGE_ID: number;
export declare const SEED_AMT: number;
export declare const TESTNET_ACCOUNT_ADDRESS = "RWVYXYLSV32QIHFUMBEBW4BQZR7FDVJGKTVZIVYECMQWU7CZUAK5Q4WMP4";
export declare const TESTNET_ACCOUNT_MN = "enforce sail meat library retreat rain praise run floor drastic flat end true olympic boy dune dust regular feed allow top universe borrow able ginger";
/**
 * <p> Creates a new Algodv2 client using local file consts</p>
 * @returns a newly constructed Algodv2 client
 */
export declare function getAlgoClient(): Algodv2;
export declare type TealCompileRsp = {
    hash: string;
    result: string;
};
export declare function textToHexString(name: string): string;
export declare function textToUint8Array(name: string): Uint8Array;
export declare function appIdToAppAddr(appId: number): string;
/**
 * <p> Return the balances of all assets for the supplied account</p>
 * @param client An Algodv2 client
 * @param account The account containing assets
 * @returns Map of asset index to qty
 */
export declare function getBalances(client: Algodv2, account: string): Promise<Map<number, number>>;
/**
 * <p>Return the balance of the supplied asset index for the supplied account</p>
 * @param client An Algodv2 client
 * @param account The account to query for the supplied asset index
 * @param key The asset index
 * @returns The quantity of the asset in the supplied account
 */
export declare function getBalance(client: Algodv2, account: string, key: number): Promise<number>;
/**
 * <p>Return the message fee for the core bridge</p>
 * @returns The message fee for the core bridge
 */
export declare function getMessageFee(client: Algodv2): Promise<number>;
/**
 * <p>Parses the logs of a transaction looking for the sequence number</p>
 * @param txn The transaction containing a sequence number
 * @returns The sequence number found in the supplied transaction
 */
export declare function parseSeqFromLog(txn: any): bigint;
/**
 * <p>Attest an already created asset</p>
 * If you create a new asset on algorand and want to transfer it elsewhere,
 * you create an attestation for it on algorand... pass that vaa to the target chain..
 * submit it.. then you can transfer from algorand to that target chain
 * @param client An Algodv2 client
 * @param senderAcct The account paying fees
 * @param assetId The asset index
 * @returns Transaction ID
 */
export declare function attestFromAlgorand(client: Algodv2, senderAcct: Account, assetId: number): Promise<string>;
/**
 * <p>Checks to see it the account exists for the application</p>
 * @param client An Algodv2 client
 * @param appId Application ID
 * @param acctAddr Account address to check
 * @returns true, if account exists for application.  Otherwise, returns false
 */
export declare function accountExists(client: Algodv2, appId: number, acctAddr: string): Promise<boolean>;
export declare function optin(client: algosdk.Algodv2, sender: Account, appId: number, appIndex: number, emitterId: string, why: string): Promise<string>;
export declare function getLogicSigAccount(program: Uint8Array): LogicSigAccount;
/**
 * <p>Parses the VAA into a Map</p>
 * @param vaa The VAA to be parsed
 * @returns The Map<string, any> containing the parsed elements of the VAA
 */
export declare function parseVAA(vaa: Uint8Array): Map<string, any>;
export declare function decodeLocalState(client: Algodv2, appId: number, address: string): Promise<Uint8Array>;
export declare function assetOptinCheck(client: Algodv2, asset: number, receiver: string): Promise<boolean>;
export declare function assetOptin(client: Algodv2, sender: Account, asset: number, receiver: string): Promise<void>;
declare class SubmitVAAState {
    vaaMap: Map<string, any>;
    accounts: string[];
    txns: Array<algosdk.Transaction>;
    guardianAddr: string;
    constructor(vaaMap: Map<string, any>, accounts: string[], txns: Array<algosdk.Transaction>, guardianAddr: string);
}
/**
 * <p>Submits just the header of the VAA</p>
 * @param vaa The VAA (Just the header is used)
 * @param client AlgodV2 client
 * @param sender Sending account
 * @param appid Application ID
 * @returns Current VAA state
 */
export declare function submitVAAHdr(vaa: Uint8Array, client: Algodv2, sender: Account, appid: number): Promise<SubmitVAAState>;
/**
 * <p>Groups the transactions together, signs them, sends them, waits for a confirmation</p>
 * @param client AlgodV2 client
 * @param sender Sending account
 * @param txns One or more transactions to send
 * @returns Confirmation log
 */
export declare function simpleSignVAA(client: Algodv2, sender: Account, txns: Array<algosdk.Transaction>): Promise<string[]>;
/**
 * </p>Submits the VAA to the application
 * @param vaa The VAA to be submitted
 * @param client AlgodV2 client
 * @param sender Sending account
 * @param appid Application ID
 * @returns Confirmation log
 */
export declare function submitVAA(vaa: Uint8Array, client: Algodv2, sender: Account, appid: number): Promise<string[]>;
export declare function getVAA(client: Algodv2, sender: Account, sid: bigint, app: number): Promise<Uint8Array>;
/**
 * <p>Transfers an asset from Algorand to a receiver on another chain</p>
 * @param client AlgodV2 client
 * @param sender Sending account
 * @param assetId Asset index
 * @param qty Quantity to transfer
 * @param receiver Receiving account
 * @param chain Reeiving chain
 * @param fee Transfer fee
 * @returns Sequence number of confirmation
 */
export declare function transferAsset(client: Algodv2, sender: Account, assetId: number, qty: number, receiver: Account, chain: number, fee: number): Promise<bigint>;
export declare function createWrappedOnAlgorand(client: algosdk.Algodv2, sender: Account, attestVAA: Uint8Array): void;
export declare function updateWrappedOnAlgorand(client: algosdk.Algodv2, sender: Account, vaa: Uint8Array): void;
/**
 * <p>This basically just submits the VAA to Algorand</p>
 * @param vaa The VAA to be redeemed
 * @param client AlgodV2 client
 * @param acct Sending account
 * @param tokenId Token bridge ID
 * @returns Transaction ID(s)
 */
export declare function redeemOnAlgorand(vaa: Uint8Array, client: Algodv2, acct: Account, tokenId: number): Promise<string[]>;
export declare function getForeignAssetAlgorand(client: Algodv2, algoTokenBridgeAddress: string, orginChain: ChainId, originAsset: Uint8Array): Promise<string>;
/**
 *
 * @param client AlgodV2 client
 * @param signedVAA VAA to check
 * @param appId Most likely the Token bridge ID
 * @param wallet The account paying the bill for this (it isn't free)
 * @returns true if VAA has been redeemed, false otherwise
 */
export declare function getIsTransferCompletedAlgorand(client: Algodv2, signedVAA: Uint8Array, appId: number, wallet: Account): Promise<boolean>;
export declare function getIsWrappedAssetAlgorand(): void;
export declare function hexToNativeString(): void;
export declare function nativeToHexString(): void;
/**
 * <p>Transfer the amount of an asset from Algorand to a different chain</p>
 * @param client AlgodV2 client
 * @param sender Holder of the asset
 * @param assetId Asset index on Algorand
 * @param quantity Amount to be transferred
 * @param receiver Receiving account
 * @param chain Receiving chain ID
 * @param fee Message fee to be paid
 */
export declare function transferFromAlgorand(client: algosdk.Algodv2, sender: Account, assetId: number, quantity: number, receiver: Account, chain: number, fee: number): Promise<void>;
export {};
